package net.eq2online.console;

import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.lang.reflect.Method;
import java.text.MessageFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * Macros log writer
 * 
 * @author Adam Mummery-Smith
 */
public final class Log
{
	/**
	 * Output stream to send log messages to 
	 */
	private static final PrintStream outputStream;
	
    /**
     * Date format for log entries
     */
    private static final SimpleDateFormat simpleDateFormatLogFormatter = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    
    static
    {
    	PrintStream printStream = System.err;
    	
    	try
    	{
    		Class<?> liteLoaderClass = Class.forName("com.mumfrey.liteloader.core.LiteLoader");
    		if (liteLoaderClass != null)
    		{
    			Method mGetRevision = liteLoaderClass.getDeclaredMethod("getRevision");
    			int revision = (Integer)mGetRevision.invoke(null);
    			if (revision >= 7)
    			{
    				Method mGetConsoleStream = liteLoaderClass.getDeclaredMethod("getConsoleStream");
    				printStream = (PrintStream)mGetConsoleStream.invoke(null);
    			}
    		}
    	}
    	catch (Throwable th) { th.printStackTrace(); }

		outputStream = printStream;
    }
    
	/**
	 * Write an entry to the log
	 * 
	 * @param info
	 */
	public static void info(final String info)
	{
		outputStream.println(simpleDateFormatLogFormatter.format(new Date()) + " [MACROS] " + info);
	}
    
	/**
	 * Write an object value to the log
	 * 
	 * @param info
	 */
	public static void info(final Object data)
	{
		if (data == null) return;
		outputStream.println(simpleDateFormatLogFormatter.format(new Date()) + " [MACROS] [" + data.getClass().getSimpleName() + "] " + data.toString());
	}

	/**
	 * Write a formatted entry to the log
	 * 
	 * @param format
	 * @param args
	 */
	public static void info(final String format, final Object... args)
	{
		outputStream.println(simpleDateFormatLogFormatter.format(new Date()) + " [MACROS] " + MessageFormat.format(format, args));
	}
	
	/**
	 * Print a stack trace for the specified throwable to the log
	 * 
	 * @param th
	 */
	public static void printStackTrace(final Throwable th)
	{
		StringWriter writer = new StringWriter();
		th.printStackTrace(new PrintWriter(writer));
		String stackTrace = writer.toString();
		Log.info(stackTrace);
	}
}
